==> prosessilouhinta-2022.9.24.tar.gz: prosessilouhinta-2022.9.24/docs/index.md <==
# prosessilouhinta

Process mining (Finnish prosessilouhinta) from eventlogs.

Given a CSV file containing an eventlog with case IDs, acitivities/tasks, user IDs, 
and timestamps some evaluations are performed that may assist in process mining.

[License: MIT](https://git.sr.ht/~sthagen/prosessilouhinta/tree/default/item/LICENSE)

[![version](https://img.shields.io/pypi/v/prosessilouhinta.svg?style=flat)](https://pypi.python.org/pypi/prosessilouhinta/)
[![downloads](https://img.shields.io/pypi/dm/prosessilouhinta.svg?style=flat)](https://pypi.python.org/pypi/prosessilouhinta/)
[![wheel](https://img.shields.io/pypi/wheel/prosessilouhinta.svg?style=flat)](https://pypi.python.org/pypi/prosessilouhinta/)
[![supported-versions](https://img.shields.io/pypi/pyversions/prosessilouhinta.svg?style=flat)](https://pypi.python.org/pypi/prosessilouhinta/)
[![supported-implementations](https://img.shields.io/pypi/implementation/prosessilouhinta.svg?style=flat)](https://pypi.python.org/pypi/prosessilouhinta/)

## Bug Tracker

Feature requests and bug reports are best entered in the [todos of prosessilouhinta](https://todo.sr.ht/~sthagen/prosessilouhinta).

## Primary Source repository

The primary source of `prosessilouhinta` lives somewhere on a mountain in Central Switzerland.
But, we use decentralized version control (git), so any clone can become the source to everyone's benefit, no central only code.
Anyway, the preferred public clones of `prosessilouhinta` are:

* [on codeberg](https://codeberg.org/sthagen/prosessilouhinta) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/prosessilouhinta) - a collection of tools useful for software development.

==> prosessilouhinta-2022.11.13.tar.gz: prosessilouhinta-2022.11.13/docs/index.md <==
# prosessilouhinta

Process mining (Finnish prosessilouhinta) from eventlogs.

Given a CSV file containing an eventlog with case IDs, acitivities/tasks, user IDs, 
and timestamps some evaluations are performed that may assist in process mining.

[License: MIT](https://git.sr.ht/~sthagen/prosessilouhinta/tree/default/item/LICENSE)

[![version](https://img.shields.io/pypi/v/prosessilouhinta.svg?style=flat)](https://pypi.python.org/pypi/prosessilouhinta/)
[![downloads](https://pepy.tech/badge/prosessilouhinta/month)](https://pepy.tech/project/prosessilouhinta)
[![wheel](https://img.shields.io/pypi/wheel/prosessilouhinta.svg?style=flat)](https://pypi.python.org/pypi/prosessilouhinta/)
[![supported-versions](https://img.shields.io/pypi/pyversions/prosessilouhinta.svg?style=flat)](https://pypi.python.org/pypi/prosessilouhinta/)
[![supported-implementations](https://img.shields.io/pypi/implementation/prosessilouhinta.svg?style=flat)](https://pypi.python.org/pypi/prosessilouhinta/)

## Bug Tracker

Feature requests and bug reports are best entered in the [todos of prosessilouhinta](https://todo.sr.ht/~sthagen/prosessilouhinta).

## Primary Source repository

The primary source of `prosessilouhinta` lives somewhere on a mountain in Central Switzerland.
But, we use decentralized version control (git), so any clone can become the source to everyone's benefit, no central only code.
Anyway, the preferred public clones of `prosessilouhinta` are:

* [on codeberg](https://codeberg.org/sthagen/prosessilouhinta) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/prosessilouhinta) - a collection of tools useful for software development.
